@@ -42,7 +42,7 @@ methods :meth:`~ae.gui_app.MainAppBase.init_app` and :meth:`~HelpAppBase.ensure_
             ...
 
 to activate the help mode the widget to display the help texts have to be assigned to the main app attribute
-:attr:`~HelpAppBase.help_layout` and to the framework app property :attr:`~ae.kivy_app.FrameworkApp.help_layout` via
+:attr:`~HelpAppBase.help_layout` and to the framework app property :attr:`~ae.kivy.apps.FrameworkApp.help_layout` via
 the :meth:`~ae.gui_app.MainAppBase.change_observable` method::
 
     main_app.change_observable('help_layout', HelpScreenContainerOrWindow())
@@ -57,8 +57,9 @@ help mode activation. the :meth:`~HelpAppBase.help_display` is using it as fallb
 widget to be explained) got found.
 
 .. hint::
-    the de-/activation method :meth:`~ae.kivy_app.KivyMainApp.help_activation_toggle` together with the classes
-    :class:`~ae.kivy_help.HelpBehavior`, :class:`~ae.kivy_help.HelpToggler` and :class:`~ae.kivy_help.Tooltip` are
+    the de-/activation method :meth:`~ae.kivy.apps.KivyMainApp.help_activation_toggle` together with the classes
+    :class:`~ae.kivy.behaviors.HelpBehavior`, :class:`~ae.kivy.widgets.HelpToggler` and
+    :class:`~ae.kivy.widgets.Tooltip` are
     demonstrating a typical implementation of help activator and help text tooltip widgets.
 
 
@@ -199,7 +200,7 @@ UI-specific implementation
 to complete the implementation of the app tours, the UI-specific framework has to provide a tour layout class, which is
 highlighting the widget explained and to display a tooltip and the tour page texts.
 
-.. hint:: the :class:`~ae.kivy_help.TourOverlay` class is a quite complete implementation of a tour layout class.
+.. hint:: the :class:`~ae.kivy.tours.TourOverlay` class is a quite complete implementation of a tour layout class.
 
 optionally for the 'user_registration' page of the :class:`OnboardingTour` an open username editor flow has to be
 implemented.
@@ -216,7 +217,7 @@ from ae.gui_app import (
     flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs)
 
 
-__version__ = '0.3.47'
+__version__ = '0.3.48'
 
 
 register_package_translations()
@@ -631,7 +632,7 @@ class TourBase:
 
         main_app = self.main_app
         delay = self.page_data.get('next_page_delay', 30.9)
-        main_app.vpo(f"TourOverlay.request_auto_page_switch from #{self.page_idx} to #{next_idx} delay={delay}")
+        main_app.vpo(f"TourBase.request_auto_page_switch from #{self.page_idx} to #{next_idx} delay={delay}")
         self._auto_switch_page_request = main_app.call_method_delayed(
             delay, self.prev_page if self.auto_switch_pages < 0 else self.next_page)
 
@@ -1104,7 +1105,7 @@ class HelpAppBase(MainAppBase, ABC):
                 # first look for widget with help_id attr in kv/enaml rule call stack frame for translation text context
                 depth = 1
                 while depth <= 15:
-                    _gfv, lfv, _deep = stack_vars("", min_depth=depth, max_depth=depth)  # "" to not skip ae.kivy_help
+                    _gfv, lfv, _deep = stack_vars("", min_depth=depth, max_depth=depth)  # "" to not skip ae.kivy module
                     widget = lfv.get('self')
                     if getattr(widget, 'help_id', None) == help_id:
                         help_vars.update(lfv)
